#!/bin/sh
SRC_URL=http://www.diracvideo.org//download/dirac-research
DOC_URL=http://www.diracvideo.org//download/dirac-research/documentation
#
# Dirac is an advanced royalty-free video compression format designed
# for a wide range of uses, from delivering low-resolution web content
# to broadcasting HD and beyond, to near-lossless studio editing.
#
# The most important part of the Dirac project is the specification,
# which can be found here: http://www.diracvideo.org/specifications
#
# script by: til <rob DOT til DOT freedman AT googlemail DOT com>
CWD=`pwd`
set -e -u -x

name=dirac
version=1.0.2

build=${build:-60.1}
arch=${arch:-i686}
cpu=pentium-m
cpu=${cpu:-i686}

TMP=${TMP:-$CWD/tmp}
pkgname=$name-$version
package=$pkgname-$arch-$build

PKG_DEP=
PKG_SRC="http://zenwalk.pinguix.com/user-accounts/tilderb/extra/dirac/build-dirac.sh
$SRC_URL/$pkgname.tar.gz"

# check source exists
for url in $PKG_SRC;do [ ! -e ${url##*/} ] && wget -N -c $url; done

PKG=$TMP/$package
SRC=$TMP/$pkgname

[ -d $SRC ] && rm -fr $SRC
[ -d $PKG ] && rm -fr $PKG

# prepare build directory
mkdir -p $SRC $PKG/{install,usr/{src,doc}/$pkgname}

tar xf $CWD/$pkgname.tar.gz --strip-components=1 -C $SRC
cd $SRC
 ./configure --help

CFLAGS="-O2 -march=$arch -mtune=$cpu " \
CXXFLAGS="-O2 -march=$arch -mtune=$cpu " \
 ./configure --prefix=/usr --enable-static=no --with-html-dir=/usr/doc/$pkgname/

make || exit 1
make install DESTDIR=$PKG
(cd $PKG;find usr)
# api docs
tar cjf $PKG/usr/doc/$pkgname/api_html.tar.bz2 \
     -C $PKG/usr/share/doc/dirac/code/ api_html
 rm -fr $PKG/usr/share/doc

# more docs
cp README COPYING $PKG/usr/doc/$pkgname
echo $DOC_URL >$PKG/usr/doc/$pkgname/docs.url

# strip symbols
find $PKG | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs -r strip --strip-unneeded
find $PKG | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs -r strip --strip-unneeded
find $PKG | xargs file | grep "current ar archive" | cut -f 1 -d : | xargs -r strip -g

# copy build script
cp $CWD/build-$name.sh $PKG/usr/src/$pkgname

# slack description
#    |-----handy-ruler------------------------------------------------------|
cat <<EOF > $PKG/install/slack-desc
$name: dirac (is a video compression format)
$name:
$name: Dirac is an advanced royalty-free video compression format designed
$name: for a wide range of uses, from delivering low-resolution web content
$name: to broadcasting HD and beyond, to near-lossless studio editing.
$name:
$name: The most important part of the Dirac project is the specification,
$name: which can be found here: http://www.diracvideo.org/specifications
$name:
EOF

# clean up
find $PKG -type d -empty -delete
cd $PKG
rootworker=$(which fakeroot 2>/dev/null) || { [ "$UID" != "0" ] && { echo "need fakeroot"; exit 1; } }
$rootworker /sbin/makepkg -l y -c n $CWD/$package.tgz

cd $CWD
echo -n $PKG_DEP >$package.dep
echo "$PKG_SRC" >$package.src
md5sum $package.tgz >$package.md5

#rm -fr $SRC $PKG
